import React, { Suspense, lazy } from 'react';
import SEOHead from '../../components/shared/SEOHead';
import { HeroSection } from '../../components/landing/HeroSection';
import { DemoVideoSection } from '../../components/landing/DemoVideoSection';
import { generateFAQStructuredData, COMMON_FAQS } from '../../utils/seo';
// Import performance utilities for scroll performance testing
import '../../utils/performanceUtils';

// OPTIMIZATION: Lazy load below-the-fold sections for faster initial render
const PricingSection = lazy(() => import('../../components/landing/PricingSection').then(module => ({ default: module.PricingSection })));
const ContactSection = lazy(() => import('../../components/landing/ContactSection').then(module => ({ default: module.ContactSection })));
const Footer = lazy(() => import('../../components/landing/Footer').then(module => ({ default: module.Footer })));
const TemplatesLanding = lazy(() => import('../../components/landing/TemplatesLanding').then(module => ({ default: module.TemplatesLanding })));
const StockVideosLanding = lazy(() => import('../../components/landing/StockVideosLanding').then(module => ({ default: module.StockVideosLanding })));
const TimelineSection = lazy(() => import('../../components/landing/TimelineSection').then(module => ({ default: module.TimelineSection })));
const FeaturesSection = lazy(() => import('../../components/landing/FeaturesSection').then(module => ({ default: module.FeaturesSection })));
const DoneForYouSection = lazy(() => import('../../components/landing/DoneForYouSection').then(module => ({ default: module.DoneForYouSection })));

export default function Landing() {
  // Enhanced FAQ data for homepage
  const homepageFAQs = [
    ...COMMON_FAQS,
    {
      question: "How quickly can I create political graphics?",
      answer: "With Advocacy Lab's templates, you can create professional political graphics in minutes. Simply choose a template, customize it with your content, and download."
    },
    {
      question: "Are the templates suitable for all types of political campaigns?",
      answer: "Yes! Our templates are designed for federal, state, and local campaigns, as well as advocacy organizations, ballot initiatives, and political causes."
    },
    {
      question: "Can I use these templates for commercial purposes?",
      answer: "Absolutely! All templates come with commercial usage rights, perfect for political consultants, agencies, and professional campaign organizations."
    }
  ];

  const faqStructuredData = generateFAQStructuredData(homepageFAQs);

  // Enhanced structured data for homepage
  const enhancedStructuredData = {
    "@context": "https://schema.org",
    "@graph": [
      {
        "@type": "Organization",
        "@id": "https://advocacylab.io/#organization",
        "name": "Advocacy Lab",
        "url": "https://advocacylab.io",
        "logo": {
          "@type": "ImageObject",
          "url": "https://advocacylab.io/images/logos/logo-big-colored.png",
          "width": 512,
          "height": 512
        },
        "description": "Professional political creative platform providing 500+ templates for campaigns and advocacy groups",
        "foundingDate": "2023",
        "industry": "Political Technology",
        "areaServed": "United States",
        "knowsAbout": ["Political Marketing", "Campaign Design", "Advocacy Graphics", "Election Materials"],
        "sameAs": [
          "https://twitter.com/advocacylab",
          "https://linkedin.com/company/advocacylab"
        ]
      },
      {
        "@type": "WebSite",
        "@id": "https://advocacylab.io/#website",
        "url": "https://advocacylab.io",
        "name": "Advocacy Lab",
        "description": "The fastest way to launch high-impact political creative. Featuring 500+ templates for campaigns and causes.",
        "publisher": {
          "@id": "https://advocacylab.io/#organization"
        },
        "inLanguage": "en-US",
        "potentialAction": {
          "@type": "SearchAction",
          "target": "https://advocacylab.io/templates?search={search_term_string}",
          "query-input": "required name=search_term_string"
        }
      },
      {
        "@type": "SoftwareApplication",
        "@id": "https://advocacylab.io/#software",
        "name": "Advocacy Lab Platform",
        "applicationCategory": "Design Tool",
        "operatingSystem": "Web",
        "offers": {
          "@type": "Offer",
          "price": "0",
          "priceCurrency": "USD",
          "availability": "https://schema.org/InStock"
        },
        "description": "Professional political creative platform with 500+ templates for campaigns, elections, and advocacy work",
        "featureList": [
          "500+ Political Templates",
          "Drag & Drop Editor",
          "Multiple File Formats",
          "Brand Customization",
          "Print & Digital Ready"
        ],
        "screenshot": "https://advocacylab.io/images/screenshots/screen1.png",
        "aggregateRating": {
          "@type": "AggregateRating",
          "ratingValue": "4.8",
          "ratingCount": "250",
          "bestRating": "5"
        },
        "publisher": {
          "@id": "https://advocacylab.io/#organization"
        }
      },
      faqStructuredData
    ]
  };

  return (
    <div className="relative min-h-screen">
      <SEOHead 
        pageType="home"
        structuredDataOverride={enhancedStructuredData}
        breadcrumbs={[
          { name: "Home", url: "https://advocacylab.io" }
        ]}
      />
      
      {/* CRITICAL: Above-the-fold content loads immediately */}
      <HeroSection />
      <DemoVideoSection />
      
      {/* OPTIMIZATION: Below-the-fold content lazy loads for faster initial render */}
      <Suspense fallback={<div className="h-20"></div>}>
        <TemplatesLanding />
      </Suspense>
      
      <Suspense fallback={<div className="h-20"></div>}>
        <FeaturesSection />
      </Suspense>
      
      <Suspense fallback={<div className="h-20"></div>}>
        <StockVideosLanding />
      </Suspense>
      
      <Suspense fallback={<div className="h-20"></div>}>
        <TimelineSection />
      </Suspense>
      
      <Suspense fallback={<div className="h-20"></div>}>
        <PricingSection />
      </Suspense>
      
      <Suspense fallback={<div className="h-20"></div>}>
        <DoneForYouSection />
      </Suspense>
      
      <Suspense fallback={<div className="h-20"></div>}>
        <ContactSection />
      </Suspense>
      
      <Suspense fallback={<div className="h-20"></div>}>
        <Footer />
      </Suspense>
    </div>
  );
}